@@ -219,8 +219,14 @@ globus_l_gfs_log_usage_stats_init()
             globus_malloc(sizeof(globus_l_gfs_log_usage_ent_t));
 
         usage_ent->target = target_str;
-        usage_ent->taglist = globus_libc_strdup(GLOBUS_GFS_DEFAULT_TAGLIST);
-
+        if(globus_i_gfs_config_string("usage_stats_id"))
+        {
+            usage_ent->taglist = globus_libc_strdup(GLOBUS_GFS_DEFAULT_TAGLIST "C");
+        }
+        else
+        {
+            usage_ent->taglist = globus_libc_strdup(GLOBUS_GFS_DEFAULT_TAGLIST);
+        }
         globus_list_insert(&globus_l_gfs_log_usage_handle_list, usage_ent);
     }
 
@@ -379,6 +385,8 @@ globus_i_gfs_log_open()
     else if(strcmp(module, "syslog") == 0)
     {
         log_mod = &globus_logging_syslog_module;
+        log_mask |= GLOBUS_LOGGING_INLINE;
+        GlobusTimeReltimeSet(flush_interval, 0, 0);
     }
     else if(strcmp(module, "stdio_ng") == 0)
     {
@@ -393,6 +401,8 @@ globus_i_gfs_log_open()
         globus_l_gfs_log_events = GLOBUS_TRUE;
         log_mask |= GLOBUS_GFS_LOG_INFO | 
             GLOBUS_GFS_LOG_WARN | GLOBUS_GFS_LOG_ERR;
+        log_mask |= GLOBUS_LOGGING_INLINE;
+        GlobusTimeReltimeSet(flush_interval, 0, 0);            
     }
     else
     {
@@ -611,7 +621,12 @@ globus_gfs_log_message(
         globus_logging_vwrite(globus_l_gfs_log_handle, type, format, ap);
         va_end(ap);
     }
-
+    
+    if(type == GLOBUS_GFS_LOG_ERR && globus_l_gfs_log_handle)
+    {
+        globus_logging_flush(globus_l_gfs_log_handle);
+    }
+        
     GlobusGFSDebugExit();
 }
 
@@ -848,7 +863,7 @@ globus_i_gfs_log_create_transfer_event_msg(
         "streams=%d "
         "stripes=%d "
         "remoteIP=%s "
-        "type=%s ",
+        "type=%s",
         username,
         fname,
         (long) tcp_bs,
